@@ -539,7 +539,7 @@ ringtoned_dispatcher_finalize (GObject *object)
     }
 
     g_list_foreach (self->priv->plugins, (GFunc) g_module_close, NULL);
-    g_list_free (self->priv->calls);
+    g_list_free (self->priv->plugins);
 
     while (self->priv->filters)
     {
@@ -557,8 +557,14 @@ ringtoned_dispatcher_finalize (GObject *object)
     dbus_connection_remove_filter (self->priv->connection,
             message_filter, self);
 
+    /* This makes ringtoned crash on scratchbox and sometimes on the N900
+     * too.
+     * It looks like a bug in PA, so we work it around. It's not a real
+     * problem as the dispatcher is freed only on exit. */
+    /*
     if (self->priv->pa_ctx)
         pa_context_unref (self->priv->pa_ctx);
+    */
 
     G_OBJECT_CLASS (ringtoned_dispatcher_parent_class)->finalize (object);
 }
